@@ -41,6 +41,7 @@ from . import adapter_ficwadcom
 from . import adapter_fimfictionnet
 from . import adapter_mediaminerorg
 from . import adapter_potionsandsnitches
+from . import adapter_tenhawkpresents
 from . import adapter_adastrafanficcom
 from . import adapter_tthfanficorg
 from . import adapter_twilightednet
@@ -165,6 +166,7 @@ from . import adapter_hentaifoundrycom
 from . import adapter_mugglenetfanfictioncom
 from . import adapter_swiorgru
 from . import adapter_fanficsme
+from . import adapter_archivehpfanfictalkcom
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
