@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2013 Fanficdownloader team, 2019 FanFicFare team
+# Copyright 2013 Fanficdownloader team, 2020 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -113,6 +113,10 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
             logger.info("Login Required for URL %s" % loginUrl)
             raise exceptions.FailedToLogin(url,params['theusername'])
 
+        ## fetch 'v' code from login page.
+        soup = self.make_soup(self._fetchUrl(loginUrl,usecache=False))
+        params['v']=soup.find('input', {'name':'v'})['value']
+
         try:
             d = self._postUrl(loginUrl,params,usecache=False)
             self.needToLogin = False
@@ -296,7 +300,6 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
         # Parse the description field for the series or universe and the
         # actual description.
 
-        desc = description_element.contents[0]
         try:
             a = description_element.find('a', href=re.compile(r"/series/\d+/.*"))
             # logger.debug("Looking for series - a='{0}'".format(a))
@@ -316,7 +319,6 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
                     series_name = re.sub(r' . a (series by|collection from).*$','',series_name)
                     # logger.debug("Series name: '%s'" % series_name)
                 self.setSeries(series_name, i)
-                desc = description_element.contents[2]
                 # Check if series is in a universe
                 if self.has_universes:
                     universe_url = self.story.getList('authorUrl')[0]  + "&type=uni"
@@ -350,7 +352,6 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
             # logger.debug("Looking for universe - a='{0}'".format(a))
             if a:
                 self.story.setMetadata("universe",stripHTML(a))
-                desc = description_element.contents[2]
                 # Assumed only one universe, but it does have a URL--use universeHTML
                 universe_name = stripHTML(a)
                 universeUrl = 'https://'+self.host+a['href']
@@ -380,7 +381,18 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
             raise
             pass
 
-        self.setDescription('https://'+self.host+'/s/'+self.story.getMetadata('storyId'),desc)
+        # There's nothing around the desc to grab it by, and there's a
+        # variable number of links before it.
+        for line in description_element.contents:
+            line = unicode(line)
+            if line.strip() == '' or line.startswith("<span") or line.startswith("<br"):
+                # skip empty, <span (universe, series or context) and <br>.
+                # logger.debug("Discard: %s"%line)
+                pass
+            else:
+                # logger.debug("Use: %s"%line)
+                self.setDescription('https://'+self.host+'/s/'+self.story.getMetadata('storyId'),line)
+                break
 
     def parseDate(self,label):
         # date is passed as a timestamp and converted in JS.  used to
@@ -541,7 +553,12 @@ class StoriesOnlineNetAdapter(BaseSiteAdapter):
             while a != None:
                 # logger.debug("before dates: {0}".format(a))
                 b = a.previousSibling
-                a.extract()
+                if a.name == 'h2' and self.getConfig('inject_chapter_title'):
+                    # keep chapter header, but make match usual size.
+                    # will double up unless chapter_start is also changed
+                    a.name = 'h3'
+                else:
+                    a.extract()
                 a = b
             for a in pagetag.findAll('div', {'class' : 'date'}):
                 a.extract()
