@@ -40,7 +40,7 @@ else: # > 3.0
     def pickle_load(f):
         return pickle.load(f,encoding="bytes")
 
-version="3.15.0"
+version="3.18.0"
 os.environ['CURRENT_VERSION_ID']=version
 
 global_cache = 'global_cache'
@@ -548,13 +548,13 @@ def get_configuration(url,
     homepath = join(expanduser('~'), '.fanficdownloader')
     ## also look for .fanficfare now, give higher priority than old dir.
     homepath2 = join(expanduser('~'), '.fanficfare')
-    xdgpath = os.environ.get('XDG_CONFIG_HOME', default=join(expanduser('~'),'.config'))
+    xdgpath = os.environ.get('XDG_CONFIG_HOME', join(expanduser('~'),'.config'))
     xdgpath = join(xdgpath, 'fanficfare')
 
     if passed_defaultsini:
         # new StringIO each time rather than pass StringIO and rewind
         # for case of list download.  Just makes more sense to me.
-        configuration.readfp(StringIO(passed_defaultsini))
+        configuration.readfp(StringIO(unicode(passed_defaultsini)))
     else:
         # don't need to check existance for our selves.
         conflist.append(join(dirname(__file__), 'defaults.ini'))
@@ -566,7 +566,7 @@ def get_configuration(url,
     if passed_personalini:
         # new StringIO each time rather than pass StringIO and rewind
         # for case of list download.  Just makes more sense to me.
-        configuration.readfp(StringIO(passed_personalini))
+        configuration.readfp(StringIO(unicode(passed_personalini)))
 
     conflist.append(join(homepath, 'personal.ini'))
     conflist.append(join(homepath2, 'personal.ini'))
