@@ -231,7 +231,7 @@ def get_valid_set_options():
                'clean_chapter_titles':(['literotica.com'],None,boollist),
                'description_in_chapter':(['literotica.com'],None,boollist),
 
-               'inject_chapter_title':(['asianfanfics.com'],None,boollist),
+               'inject_chapter_title':(['asianfanfics.com','storiesonline.net','finestories.com'],None,boollist),
 
                'auto_sub':(['asianfanfics.com'],None,boollist),
 
@@ -267,9 +267,11 @@ def get_valid_set_options():
                'replace_failed_smilies_with_alt_text':(base_xenforo_list,None,boollist),
                'use_threadmark_wordcounts':(base_xenforo_list,None,boollist),
                'always_include_first_post_chapters':(base_xenforo_list,None,boollist),
+               'order_threadmarks_by_date':(base_xenforo_list,None,boollist),
                'use_threadmarks_description':(base_xenforo2_list,None,boollist),
                'use_threadmarks_status':(base_xenforo2_list,None,boollist),
                'use_threadmarks_cover':(base_xenforo2_list,None,boollist),
+               'skip_sticky_first_posts':(base_xenforo2_list,None,boollist),
                'fix_pseudo_html': (['webnovel.com'], None, boollist),
                'fix_excess_space': (['novelonlinefull.com', 'novelall.com'], ['epub', 'html'], boollist)
                }
@@ -422,6 +424,7 @@ def get_valid_keywords():
                  'remove_transparency',
                  'replace_br_with_p',
                  'replace_hr',
+                 'replace_xbr_with_hr',
                  'replace_metadata',
                  'slow_down_sleep_time',
                  'sort_ships',
@@ -480,15 +483,18 @@ def get_valid_keywords():
                  'replace_failed_smilies_with_alt_text',
                  'use_threadmark_wordcounts',
                  'always_include_first_post_chapters',
+                 'order_threadmarks_by_date',
                  'use_threadmarks_description',
                  'use_threadmarks_status',
                  'use_threadmarks_cover',
+                 'skip_sticky_first_posts',
                  'datethreadmark_format',
                  'fix_pseudo_html',
                  'fix_excess_space',
                  'ignore_chapter_url_list',
                  'dedup_chapter_list',
                  'max_zalgo',
+                 'epub_version',
                  ])
 
 # *known* entry keywords -- or rather regexps for them.
